==> StaticMiniForum.3.1.0.zip: lang/fr.php <==
<?php
	$LANG = array(
	'L_PAGE_TITLE'				=> 'PluginStatic Comments',
	'L_DESCRIPTION'				=> 'Description',
	'L_VERSION'					=> '3.0.0',
	
	# config multilingue 
	'L_DEFAULT_MENU_NAME'		=> 'Static Comments',
	'L_MENU_DISPLAY'			=> 'Afficher la page static au menu',
	'L_FORM_DISPLAY'			=> 'Afficher le formulaire',
	'L_MENU_TITLE'				=> 'Titre de la page et du menu',
	'L_MENU_POS'		    	=> 'Position du menu',
	'L_TEMPLATE'				=> 'Gabari',
	'L_PARAM_URL'				=> 'Nom du paramètre dans l\'url',
	
	#wizard
	'L_PREVIOUS'				=> 'Page précedente',
	'L_NEXT'					=> 'Page suivante',
	'L_CLOSE'					=> 'Fermer l\'aide',
	
	#config
	'L_SAVE'					=> 'enregistrer',
	'L_PARAMS'					=> 'Paramètres',
	'L_CONFIG'					=> 'Configuration',
	'L_CONFIG_FORUM'			=> 'Configurations du forum.',
	'L_PARAMS_FORUMS'			=> 'Paramètres du forum',


	'L_SELECT_STATIC'			=> 'Page(s) statique(s) selectionnée(s))',
	'L_NONE'			=> 'Aucun',
	'L_NONE_IN_LIST'			=> 'Aucune',
    'L_ACTIVATE_CAPCHA'			=> 'configuration captcha',
	'L_PARAMS_CAPTCHA'			=> 'activation',
	'L_PARAMS_CAPTCHA_ACTIVATE'	=> 'afficher le captcha',
    'L_CONFIG_COMMENT'			=> 'Configuration commentaires',
	'L_PARAMS_COMMENTS'			=> 'Paramètres affichage des commentaires',
	'L_PARAMS_HINT'				=> '<b style="color:tomato">!</b> Désactivez le formulaire momentanément <br> pour n\'afficher que les commentaires',
	'L_PARAMS_BY_PAGE'			=> 'Nombre par page',
	'L_IN_BETWEEN'				=> 'Afficher les liens intermediaires',
	'L_LAST_FIRST'				=> 'par ordre du plus récent',
	'L_PARAMS_STATIC'			=> 'Activation du module "commentaire".',
	'L_PATTERN_COLORS'			=> 'Èchantillon de couleurs <br>pour les badges.',
	
	
	#moderation
	'L_DELETE'					=> 'Supprimer',
	'L_VALID_DELETE'			=> 'Supprimer le(s) commentaire(s) selectioné(s)',
	
	#forum
	'L_MUST_BE_CONNECTED'		=> 'Vous devez être connecté <br>pour interagir sur le Forum.',
	'L_USERS'					=> ' Membres',
	'L_THREAD_PUBLISHED'		=> 'Sujet publié',
	'L_REPLY_PUBLISHED'			=> 'Réponse publiée',
	'WRITE_A_THREAD'			=> 'Ouvrir un nouveau sujet',
	'L_CREATED_BY'				=> 'Créer par:',
	'SUBJECT'					=> 'Titre du sujet ',
	'L_SUBJECT'					=> 'Sujet sur ce forum',
	'L_REPLYS'					=> 'Réponse(s)',
	'L_SUBJECT_REPLY'			=> 'Réponse sur ce fil',
	'L_SUBJECTS'				=> 'Sujets ouverts par les membres',
	'L_SUBJECTS_REPLY'			=> 'Réponses sur ce fil',
	'SUBJECT_CONTENT'			=> 'Contenu du sujet ',
	'SUBJECT_REPLY'				=> 'Répondre au sujet ',
	'SUBJECT_CONTENT_REPLY'		=> 'Contenu de la réponse au sujet ',
	'L_WRITE'					=> '&#13;&#13;&#9;&#9;Commencez à écrire &#13;&#9;&#9;&#9;dans cette zone.',
	'L_NO_POST'					=> 'Aucune réponse',
	'L_NO_THREAD'				=> 'Aucun',
	'L_THREAD'					=> 'Fil ',
	'L_PROFIL_ADMIN'			=> 'Administrateur',
	'L_PROFIL_MANAGER'			=> 'Gestionnaire',
	'L_PROFIL_MODERATOR'		=> 'Modérateur',
	'L_FORUM_MODERATOR'			=> 'Forum(s) modéré(s) par',
	'L_PROFIL_EDITOR'			=> 'Éditeur',
	'L_PROFIL_WRITER'			=> 'Rédacteur',
	'L_PROFIL_FORUM'			=> 'Membre du forum',
	'L_FROM_FORUM'				=> 'En direct du forum',
	'L_LAST_SUBJECT'			=> 'Dernier(s) Sujet(s) Actif(s)',
	'L_LAST_REPLY'				=> 'Derniere(s) Réponse(s)',
	'L_OTHER_FORUMS'			=> 'Liste des Forums',
	
	#signup
	
	'L_BACK'     				=> 'Accueil',
	'L_SHIFT'    				=> 'Connexion',
	'L_PASSWORD' 				=> 'Mot de passe',
	
	# config.php
	'L_SUB_TITLE'    			=> 'Permet aux internautes <br>de s’enregistrer',
	'L_MENU_DISPLAY' 			=> 'Afficher le menu &#13;pour s’enregistrer',
	'L_MENU_TITLE'   			=> 'Titre du menu',
	'L_MENU_NAME'    			=> 'S’enregistrer',
	'L_MENU_POS'     			=> 'Position du menu',
	'L_LABEL'        			=> 'Afficher les labels',
	'L_SAVE'         			=> 'Enregistrer',
	'L_ALL'          			=> 'Toujours &#13;Afficher le formulaire',
	'L_BOT'          			=> 'Formulaire visible par les robots',
	'L_SIDEBAR_NOTIFICATION'	=> 'Dans la sidebar.',
	'L_BOTTOM_NOTIFICATION'		=> 'Au pied du forum',
	'L_PARAMS_NOTIFICATIONS'	=> 'Paramétres d\'affichage <br>des notifications',
	'L_NOTIFICATION_NUMBER'		=> 'Nombre de notications.',
	'L_SHOW_OTHER_FORUMS'		=> 'Afficher Les autres Forums.',
	'L_DELETE_OBSOLETE_FILE'	=> 'Supprimer les enregistrements &#13;des Forums obsolétes.',
	'L_SUBSCRIPTION'			=> 'Modération des inscriptions',
	'L_STOP_SUBSCRIPTION'		=> 'Désactiver les inscriptions',
	'L_MODERATE_SUBSCRITION'	=> 'Les inscriptions doivent être activées  par l\'administrateur,depuis la page "Comptes Utilisateurs" ',
	'L_SUBSCRIPTION_PENDING'	=> '<p style="font-size:30px;text-align: center;line-height: 1.6;display:grid;position:fixed;inset:0;place-content:center;padding:1em;">
									Inscription Enregistrée.
									<br>Elle est en attente d&#039;activation par le Webmestre.
									<br><br> Merci à vous.
									<br><br><a href="/" style="font-size:20px;color:blue">Retour au site.</a>
									</p>',
	'L_STOPPED_SUBSCRIPTION'	=> '<br>Les inscriptions aux forums sont actuellement fermées.',
	
	# search
	'L_THREE_LETTERS'			=> 'Un minimum 3 lettres est requis pour lancer une recherche.',
	'L_RESULTS'					=> ' résultat(s)',
	'L_SEARCH_RESULTS'			=> 'Résultats de la recherche pour: ',
	'L_SEARCH_NO_RESULT'		=> 'Aucun résultat',
	'L_SEARCH_NO_SEARCHWORD'	=> 'Aucune valeur saisie',
	'L_SUBJECT_RESULTS'			=> 'Sujet(s)',
	'L_REPLY_RESULTS'			=> 'Réponse(s)',
	'L_SUBMIT_SEARCH'			=> '&#128269;',
	'L_PLACEHOLDER_SEARCH'		=> 'Rechercher ...',
	
	# et ainsi de suite pour chaque mot(s) à traduire
);

==> StaticMiniForum.3.1.1.zip: lang/fr.php <==
<?php
	$LANG = array(
	'L_PAGE_TITLE'				=> 'PluginStatic Comments',
	'L_DESCRIPTION'				=> 'Description',
	'L_VERSION'					=> '3.0.0',
	
	# config multilingue 
	'L_DEFAULT_MENU_NAME'		=> 'Static Comments',
	'L_MENU_DISPLAY'			=> 'Afficher la page static au menu',
	'L_FORM_DISPLAY'			=> 'Afficher le formulaire',
	'L_MENU_TITLE'				=> 'Titre de la page et du menu',
	'L_MENU_POS'		    	=> 'Position du menu',
	'L_TEMPLATE'				=> 'Gabari',
	'L_PARAM_URL'				=> 'Nom du paramètre dans l\'url',
	
	#wizard
	'L_PREVIOUS'				=> 'Page précedente',
	'L_NEXT'					=> 'Page suivante',
	'L_CLOSE'					=> 'Fermer l\'aide',
	
	#config
	'L_SAVE'					=> 'enregistrer',
	'L_PARAMS'					=> 'Paramètres',
	'L_CONFIG'					=> 'Configuration',
	'L_CONFIG_FORUM'			=> 'Configurations du forum.',
	'L_PARAMS_FORUMS'			=> 'Paramètres du forum',


	'L_SELECT_STATIC'			=> 'Page(s) statique(s) selectionnée(s))',
	'L_NONE'			=> 'Aucun',
	'L_NONE_IN_LIST'			=> 'Aucune',
    'L_ACTIVATE_CAPCHA'			=> 'configuration captcha',
	'L_PARAMS_CAPTCHA'			=> 'activation',
	'L_PARAMS_CAPTCHA_ACTIVATE'	=> 'afficher le captcha',
    'L_CONFIG_COMMENT'			=> 'Configuration commentaires',
	'L_PARAMS_COMMENTS'			=> 'Paramètres affichage des commentaires',
	'L_PARAMS_HINT'				=> '<b style="color:tomato">!</b> Désactivez le formulaire momentanément <br> pour n\'afficher que les commentaires',
	'L_PARAMS_BY_PAGE'			=> 'Nombre par page',
	'L_IN_BETWEEN'				=> 'Afficher les liens intermediaires',
	'L_LAST_FIRST'				=> 'tri: dernieres réponses en premier',
	'L_PARAMS_STATIC'			=> 'Activation du module "commentaire".',
	'L_PATTERN_COLORS'			=> 'Èchantillon de couleurs <br>pour les badges.',
	
	
	#moderation
	'L_DELETE'					=> 'Supprimer',
	'L_VALID_DELETE'			=> 'Supprimer le(s) commentaire(s) selectioné(s)',
	
	#forum
	'L_MUST_BE_CONNECTED'		=> 'Vous devez être connecté <br>pour interagir sur le Forum.',
	'L_USERS'					=> ' Membres',
	'L_THREAD_PUBLISHED'		=> 'Sujet publié',
	'L_REPLY_PUBLISHED'			=> 'Réponse publiée',
	'WRITE_A_THREAD'			=> 'Ouvrir un nouveau sujet',
	'L_CREATED_BY'				=> 'Créer par:',
	'SUBJECT'					=> 'Titre du sujet ',
	'L_SUBJECT'					=> 'Sujet sur ce forum',
	'L_REPLYS'					=> 'Réponse(s)',
	'L_SUBJECT_REPLY'			=> 'Réponse sur ce fil',
	'L_SUBJECTS'				=> 'Sujets ouverts par les membres',
	'L_SUBJECTS_REPLY'			=> 'Réponses sur ce fil',
	'SUBJECT_CONTENT'			=> 'Contenu du sujet ',
	'SUBJECT_REPLY'				=> 'Répondre au sujet ',
	'SUBJECT_CONTENT_REPLY'		=> 'Contenu de la réponse au sujet ',
	'L_WRITE'					=> '&#13;&#13;&#9;&#9;Commencez à écrire &#13;&#9;&#9;&#9;dans cette zone.',
	'L_NO_POST'					=> 'Aucune réponse',
	'L_NO_THREAD'				=> 'Aucun',
	'L_THREAD'					=> 'Fil ',
	'L_PROFIL_ADMIN'			=> 'Administrateur',
	'L_PROFIL_MANAGER'			=> 'Gestionnaire',
	'L_PROFIL_MODERATOR'		=> 'Modérateur',
	'L_FORUM_MODERATOR'			=> 'Forum(s) modéré(s) par',
	'L_PROFIL_EDITOR'			=> 'Éditeur',
	'L_PROFIL_WRITER'			=> 'Rédacteur',
	'L_PROFIL_FORUM'			=> 'Membre du forum',
	'L_FROM_FORUM'				=> 'En direct du forum',
	'L_LAST_SUBJECT'			=> 'Dernier(s) Sujet(s) Actif(s)',
	'L_LAST_REPLY'				=> 'Derniere(s) Réponse(s)',
	'L_OTHER_FORUMS'			=> 'Liste des Forums',
	
	#signup
	
	'L_BACK'     				=> 'Accueil',
	'L_SHIFT'    				=> 'Connexion',
	'L_PASSWORD' 				=> 'Mot de passe',
	
	# config.php
	'L_SUB_TITLE'    			=> 'Permet aux internautes <br>de s’enregistrer',
	'L_MENU_DISPLAY' 			=> 'Afficher le menu &#13;pour s’enregistrer',
	'L_MENU_TITLE'   			=> 'Titre du menu',
	'L_MENU_NAME'    			=> 'S’enregistrer',
	'L_MENU_POS'     			=> 'Position du menu',
	'L_LABEL'        			=> 'Afficher les labels',
	'L_SAVE'         			=> 'Enregistrer',
	'L_ALL'          			=> 'Toujours &#13;Afficher le formulaire',
	'L_BOT'          			=> 'Formulaire visible par les robots',
	'L_SIDEBAR_NOTIFICATION'	=> 'Dans la sidebar.',
	'L_BOTTOM_NOTIFICATION'		=> 'Au pied du forum',
	'L_PARAMS_NOTIFICATIONS'	=> 'Paramétres d\'affichage <br>des notifications',
	'L_NOTIFICATION_NUMBER'		=> 'Nombre de notications.',
	'L_SHOW_OTHER_FORUMS'		=> 'Afficher Les autres Forums.',
	'L_DELETE_OBSOLETE_FILE'	=> 'Supprimer les enregistrements &#13;des Forums obsolétes.',
	'L_SUBSCRIPTION'			=> 'Modération des inscriptions',
	'L_STOP_SUBSCRIPTION'		=> 'Désactiver les inscriptions',
	'L_MODERATE_SUBSCRITION'	=> 'Les inscriptions doivent être activées  par l\'administrateur,depuis la page "Comptes Utilisateurs" ',
	'L_SUBSCRIPTION_PENDING'	=> '<p style="font-size:30px;text-align: center;line-height: 1.6;display:grid;position:fixed;inset:0;place-content:center;padding:1em;">
									Inscription Enregistrée.
									<br>Elle est en attente d&#039;activation par le Webmestre.
									<br><br> Merci à vous.
									<br><br><a href="/" style="font-size:20px;color:blue">Retour au site.</a>
									</p>',
	'L_STOPPED_SUBSCRIPTION'	=> '<br>Les inscriptions aux forums sont actuellement fermées.',
	
	# search
	'L_THREE_LETTERS'			=> 'Un minimum 3 lettres est requis pour lancer une recherche.',
	'L_RESULTS'					=> ' résultat(s)',
	'L_SEARCH_RESULTS'			=> 'Résultats de la recherche pour: ',
	'L_SEARCH_NO_RESULT'		=> 'Aucun résultat',
	'L_SEARCH_NO_SEARCHWORD'	=> 'Aucune valeur saisie',
	'L_SUBJECT_RESULTS'			=> 'Sujet(s)',
	'L_REPLY_RESULTS'			=> 'Réponse(s)',
	'L_SUBMIT_SEARCH'			=> '&#128269;',
	'L_PLACEHOLDER_SEARCH'		=> 'Rechercher ...',
	
	# et ainsi de suite pour chaque mot(s) à traduire
);
